@@ -6,7 +6,7 @@ cs = []
 for i in range(-10, 10):
     r = 10 / (i * i + 10)
     c = Circle(r=r).rotateY(i*2).z(i/10).x(i/20)
-    c.wireframe().lineWidth(3).lineColor('k')
+    c.lineWidth(3).lineColor('blue5')
     cs.append(c)
 
 # create the mesh by merging the ribbon strips
@@ -18,4 +18,4 @@ mesh = merge(rbs).clean().cap().color('limegreen')
 
 cs.append(__doc__)
 
-show([cs, mesh], N=2, axes=1, elevation=-40, bg2='lb')
+show([cs, mesh], N=2, axes=1, elevation=-40, bg2='lb').close()
