@@ -1,12 +1,11 @@
 """Create the Convex Hull of
-a Mesh or a set of input points
-"""
+a Mesh or a set of input points"""
 from vedo import *
 
 settings.defaultFont = 'Bongas'
 
-spid = load(dataurl+"spider.ply").c("brown")
+spid = Mesh(dataurl+"spider.ply").c("brown")
 
 ch = ConvexHull(spid.points()).alpha(0.2)
 
-show(spid, ch, __doc__, axes=1)
+show(spid, ch, __doc__, axes=1).close()
