@@ -1,7 +1,5 @@
 """For each point finds the 12 closest ones and fit a sphere.
-Color points from the size of the sphere radius.
-"""
-from __future__ import division, print_function
+Color points from the size of the sphere radius."""
 from vedo import *
 from vedo.pyplot import histogram
 
@@ -31,4 +29,4 @@ plt += Lines(pts1, pts2, c="black")
 plt += histogram(vals, xtitle='radius', xlim=[0,2]).pos(-1,0.5,-1)
 plt += __doc__
 
-plt.show()
+plt.show().close()
