@@ -1,14 +1,14 @@
 """Use a variant of the Moving Least Squares (MLS)
 algorithm to project a cloud of points to become a smooth surface.
 In the second window we show the error estimated for
-each point in color scale (left) or in size scale (right).
-"""
+each point in color scale (left) or in size scale (right)."""
 from vedo import *
 import numpy as np
+printc(__doc__, invert=1)
 
-vp1 = Plotter(N=3)
+plt1 = Plotter(N=3, axes=1)
 
-mesh = vp1.load(dataurl+"bunny.obj").normalize().subdivide()
+mesh = Mesh(dataurl+"bunny.obj").normalize().subdivide()
 
 pts = mesh.points(copy=True)  # pts is a copy of the points not a reference
 pts += np.random.randn(len(pts), 3)/20  # add noise, will not mess up the original points
@@ -16,21 +16,21 @@ pts += np.random.randn(len(pts), 3)/20  # add noise, will not mess up the origin
 
 #################################### smooth cloud with MLS
 # build the mesh points
-s0 = Points(pts, r=3).color("blue").legend("original\npoint cloud")
-vp1.show(s0, at=0)
+s0 = Points(pts, r=3).color("blue")
+plt1.show(s0, "original point cloud + noise", at=0)
 
 # project s1 points into a smooth surface of points
 # The parameter f controls the size of the local regression.
-mls1 = s0.clone().smoothMLS2D(f=0.5).legend("first pass")
-vp1.show(mls1, at=1)
+mls1 = s0.clone().smoothMLS2D(f=0.5)
+plt1.show(mls1, "MLS first pass, f=0.5", at=1)
 
 # mls1 is an Assembly so unpack it to get the first object it contains
-mls2 = mls1.clone().smoothMLS2D(radius=0.1).legend("second pass")
-vp1.show(mls2, at=2)
+mls2 = mls1.clone().smoothMLS2D(radius=0.1)
+plt1.show(mls2, "MLS second pass, radius=0.1", at=2)
 
 
 #################################### draw errors
-vp2 = Plotter(pos=(300, 400), N=2)
+plt2 = Plotter(pos=(300, 400), N=2, axes=1)
 
 variances = mls2.info["variances"]
 vmin, vmax = np.min(variances), np.max(variances)
@@ -42,5 +42,6 @@ sp1 = Spheres(mls2.points(), c="red", r=variances/4) # error as point size
 
 mesh.color("k").alpha(0.05).wireframe()
 
-vp2.show(sp0, __doc__, at=0)
-vp2.show(sp1, mesh, at=1, zoom=1.3, interactive=1)
+plt2.show(sp0, "Use color to represent variance", at=0)
+plt2.show(sp1, "point size to represent variance", at=1, zoom=1.3, interactive=1).close()
+plt1.close()
