@@ -18,15 +18,15 @@ from vedo import *
 import numpy as np
 
 
-vp = Plotter(N=4, axes=0)
+plt = Plotter(N=4, axes=0)
 
-mesh = vp.load(dataurl+"apple.ply").subdivide()
-vp.show(mesh, at=0)
+mesh = plt.load(dataurl+"apple.ply").subdivide()
+plt.show(mesh, at=0)
 
 noise = np.random.randn(mesh.N(), 3) * 0.03
 
 pts0 = Points(mesh.points() + noise, r=3).legend("noisy cloud")
-vp.show(pts0, at=1)
+plt.show(pts0, at=1)
 
 pts1 = pts0.clone().smoothMLS2D(f=0.8)  # smooth cloud
 
@@ -36,8 +36,8 @@ print("Nr of points before cleaning nr. points:", pts1.N())
 pts1.clean(tol=0.005).legend("smooth cloud")
 print("             after  cleaning nr. points:", pts1.N())
 
-vp.show(pts1, at=2)
+plt.show(pts1, at=2)
 
 # reconstructed surface from point cloud
 reco = recoSurface(pts1, dims=100, radius=0.2).legend("surf. reco")
-vp.show(reco, at=3, axes=7, zoom=1.2, interactive=1)
+plt.show(reco, at=3, axes=7, zoom=1.2, interactive=1).close()
