@@ -2,8 +2,8 @@
 the red line to the yellow surface"""
 from vedo import *
 
-limb = load(dataurl + "270.vtk").c("gold").flag()
-rim  = load(dataurl + "270_rim.vtk").c("red").lw(4)
+limb = Mesh(dataurl + "270.vtk").c("gold").flag()
+rim  = Mesh(dataurl + "270_rim.vtk").c("red").lw(4)
 
 # Make a clone copy of rim and align it to limb
 # rigid=True doesn't allow scaling
@@ -18,4 +18,4 @@ printc("ave. squared distance =", d/rim2.N())
 # vtkTransform is available through:
 # printc([rim2.transform])
 
-show(limb, rim, rim2, __doc__, axes=1)
+show(limb, rim, rim2, __doc__, axes=1).close()
