@@ -2,7 +2,7 @@
 set of points (landmarks) must move"""
 from vedo import *
 
-s1 = load(dataurl + "bunny.obj").c("gold").flag('bunny1')
+s1 = Mesh(dataurl + "bunny.obj").c("gold").flag('bunny1')
 
 # Make a copy of s1 (note that this mesh is not really necessary
 # we only used it to click a bunch of points as landmarks,
@@ -29,4 +29,4 @@ s3.flag('transformed bunny')
 
 ars = Arrows(landmarksFrom, landmarksTo, s=0.5).c('k').alpha(0.5)
 
-show(s1,s2,s3, ars, __doc__, axes=True)
+show(s1,s2,s3, ars, __doc__, axes=True).close()
