@@ -3,6 +3,8 @@ passing a 1-to-1 list of colors and
 optionally a list of transparencies"""
 from vedo import *
 
+settings.useDepthPeeling = True
+
 tor = Torus(res=9).lineWidth(0.1)
 
 cols, alphas = [], []
@@ -11,6 +13,7 @@ for i in range(tor.NCells()):
     alphas.append(i/tor.NCells()) # a transparency value
 
 tor.cellIndividualColors(cols, alphas)
-print('Mesh arrays:', tor.getArrayNames())
+printc('Mesh cell arrays:', tor.celldata.keys(), 
+       'shape:', tor.celldata['CellIndividualColors'].shape)
 
 show(tor, __doc__).close()
