@@ -13,4 +13,4 @@ vtxs = s.connectedVertices(index, returnIds=False)
 apt  = Point(pt, c="r", r=15)
 cpts = Points(vtxs, c="blue", r=15)
 
-show(s, apt, cpts, __doc__, bg='bb')
+show(s, apt, cpts, __doc__, bg='bb').close()
