@@ -10,4 +10,4 @@ ids = [[24,35,36,37,26,15,14,25], [84,95,96,85]]
 pts = Points(gp, r=6).c('blue3')
 dly = delaunay2D(gp, mode='xy', boundaries=ids).c('w').lc('o').lw(1)
 
-show(pts, pts.labels('id'), dly, __doc__, bg="Mint")
+show(pts, pts.labels('id').z(0.01), dly, __doc__, bg="Mint").close()
