@@ -1,7 +1,6 @@
 """Glyphs:
 at each vertex of a mesh, another mesh
-is shown with various orientation options
-"""
+is shown with various orientation options"""
 from vedo import *
 import numpy as np
 
@@ -17,17 +16,17 @@ gsphere1 = Glyph(s, gly1,
                  scaleByVectorSize=True,
                  colorByVectorSize=True,
                  c='jet',
-                 )
+                )
 
 
 #######################################
-gly2 = load(dataurl+"shuttle.obj").rotateY(180).scale(0.02)
+gly2 = Mesh(dataurl+"shuttle.obj").rotateY(180).scale(0.02)
 
 gsphere2 = Glyph(s, gly2,
                  orientationArray="normals",
                  tol=0.1,  # minimum seaparation of 10% of bounding box
                  c='lightblue',
-                 )
+                )
 
 # show two groups of objects on N=2 renderers:
-show([(s, gsphere1, __doc__), (s, gsphere2)], N=2, bg='bb', zoom=1.4)
+show([(s, gsphere1, __doc__), (s, gsphere2)], N=2, bg='bb', zoom=1.4).close()
