@@ -16,4 +16,4 @@ show(s0, __doc__+str(N), at=0, N=2, axes=1, viewup=(-0.7, 0.7, 0))
 
 # all have same color but different radius along y:
 s1 = Spheres(pts, r=rads, c="lb", res=8)
-show(s1, at=1, axes=2, interactive=True)
+show(s1, at=1, axes=2, interactive=True).close()
