@@ -1,9 +1,8 @@
 """Create a set of transparencies
-which can be passed to method cmap()
-"""
-from vedo import load, show, dataurl
+which can be passed to method cmap()"""
+from vedo import Mesh, show, dataurl
 
-mesh = load(dataurl+"beethoven.ply")
+mesh = Mesh(dataurl+"beethoven.ply")
 
 # pick y coordinates of vertices and use them as scalars
 scals = mesh.points()[:, 1]
@@ -14,6 +13,7 @@ scals = mesh.points()[:, 1]
 alphas = [0.1, 0.1, 0.3, 0.4, 0.9]
 
 mesh.cmap("copper", scals, alpha=alphas)
-# print(mesh.getPointArray('PointScalars')) # retrieve scalars
+# mesh.print()
+# print(mesh.pointdata['PointScalars']) # retrieve scalars
 
-show(mesh, __doc__, axes=9)
+show(mesh, __doc__, axes=9).close()
