@@ -1,9 +1,8 @@
 """Extracts cells of a Mesh which satisfy
-the threshold criterion: 37 < scalar < 37.5
-"""
+the threshold criterion: 37 < scalar < 37.5"""
 from vedo import *
 
-man = load(dataurl+"man.vtk")
+man = Mesh(dataurl+"man.vtk")
 
 scals = man.points()[:, 0] + 37  # pick y coords of vertices
 
@@ -12,5 +11,5 @@ man.cmap("cool", scals).addScalarBar(title="threshold", horizontal=True)
 # make a copy and threshold the mesh
 cutman = man.clone().threshold(scals, 37, 37.5)
 
-# distribute the meshes on 2 renderers
-show([(man, __doc__), cutman], N=2, elevation=-30, axes=11)
+# distribute the meshes on the 2 renderers
+show([(man, __doc__), cutman], N=2, elevation=-30, axes=11).close()
