@@ -16,9 +16,9 @@ def onEvent(event):
 
 ######################
 tea = Mesh(dataurl+"teapot.vtk").c("gold")
-mug = Mesh(dataurl+"mug.ply").rotateX(90).scale(8).pos(2,0,-.7).c("silver")
+mug = Mesh(dataurl+"mug.ply").rotateX(90).scale(8).pos(2,0,-.7).c("red3")
 
 plt = Plotter(axes=11)
 plt.addCallback('LeftButtonPress', onLeftClick)
 plt.addCallback('Interaction', onEvent) # mouse dragging triggers this
-plt.show(tea, mug, __doc__)
+plt.show(tea, mug, __doc__).close()
