@@ -21,4 +21,4 @@ msg = Text2D("", pos="bottom-center", c='k', bg='r9', alpha=0.8)
 
 plt = Plotter(axes=1, bg='black')
 plt.addCallback('mouse click', func)
-plt.show(spheres, msg, __doc__, zoom=1.2)
+plt.show(spheres, msg, __doc__, zoom=1.2).close()
