@@ -2,7 +2,7 @@
 move along with camera position"""
 from vedo import *
 
-s = load(dataurl+'shark.ply').c('gray',0.1).lw(0.1).lc('k')
+s = Mesh(dataurl+'shark.ply').c('gray',0.1).lw(0.1).lc('k')
 
 # this call creates the camera object needed by silhouette()
 show(s, bg='db', bg2='lb', interactive=False)
