@@ -12,14 +12,15 @@ def slider2(widget, event):
     mesh.alpha(value)
 
 
-vp = Plotter(axes=0)
-mesh = vp.load(dataurl+"magnolia.vtk").flat().lw(0.1)
+plt = Plotter(axes=0)
+mesh = plt.load(dataurl+"magnolia.vtk").flat().lw(0.1)
 
-vp.addSlider2D(slider1, -9, 9, value=0,
+plt.addSlider2D(slider1, -9, 9, value=0,
                pos="bottom-right", title="color number")
 
-vp.addSlider2D(slider2, xmin=0.01, xmax=0.99, value=0.5, c="blue",
+plt.addSlider2D(slider2, xmin=0.01, xmax=0.99, value=0.5, c="blue",
                 pos="bottom-right-vertical", title="alpha value (opacity)")
 
-vp += __doc__
-vp.show()
+plt += __doc__
+plt.show()
+plt.close()
