@@ -1,11 +1,9 @@
-"""
-3D slider to move a mesh interactively
-"""
+"""3D slider to move a mesh interactively"""
 from vedo import Plotter, dataurl
 
-vp = Plotter()
+plt = Plotter(title=__doc__)
 
-mesh = vp.load(dataurl+"spider.ply")
+mesh = plt.load(dataurl+"spider.ply")
 mesh.normalize().rotateZ(190)
 
 
@@ -13,7 +11,7 @@ def slider_y(widget, event):
     value = widget.GetRepresentation().GetValue()
     mesh.y(value)  # set y coordinate position
 
-vp.addSlider3D(
+plt.addSlider3D(
     slider_y,
     pos1=[.5, -3.5, .35],
     pos2=[.5, -1.0, .35],
@@ -27,4 +25,4 @@ vp.addSlider3D(
 )
 
 
-vp.show(viewup="z", axes=11, bg='bb', bg2='navy')
+plt.show(viewup="z", axes=11, bg='bb', bg2='navy').close()
