@@ -11,7 +11,7 @@ from vedo import *
 # declare the class instance
 vp = Plotter(bg='beige', axes=10, offscreen=True)
 
-vp.load(datadir+"spider.ply").texture("leather").rotateX(-90)
+vp.load(dataurl+"spider.ply").texture("leather").rotateX(-90)
 
 # open a video file and force it to last 3 seconds in total
 video = Video("spider.mp4", duration=6, backend='ffmpeg') # backend='opencv'
