@@ -3,7 +3,7 @@ Cartesian planes can be displaced
 from their lower-range default position"""
 from vedo import Sphere, Axes, precision, show
 
-sph = Sphere().scale([4,3,2]).shift(5,6,7).c('green2', 0.1)
+sph = Sphere().scale([4,3,2]).shift(5,6,7).c('green2', 0.1).wireframe()
 
 axs = Axes(sph,          # build axes for object sph
            xtitle="x axis",
@@ -20,6 +20,6 @@ axs = Axes(sph,          # build axes for object sph
            xyShift=0.2,  # move xy plane 20% along z
            yzShift=0.2,  # move yz plane 20% along x
            zxShift=0.2,  # move zx plane 20% along y
-          )
+)
 
-show(sph, axs, __doc__)
+show(sph, axs, __doc__).close()
