@@ -20,7 +20,7 @@ pfit = fit([x, y+noise],
            deg=1,          # degree of the polynomial
            niter=500,      # nr. of MC iterations to compute error bands
            nstd=2,         # nr. of std deviations to display
-          )
+)
 
 plt += [pfit, pfit.errorBand, *pfit.errorLines] # add these objects to Plot
 
@@ -30,4 +30,4 @@ msg = f"Generated a, b  : {np.array([a,b])}"\
       f"\nave point spread: \sigma \approx {pfit.dataSigma:.3f} in y units"
 msg = Text2D(msg, font='VictorMono', pos='bottom-left', c='red3')
 
-show(plt, msg)
+show(plt, msg, mode="image").close()
