@@ -14,7 +14,7 @@ hst1 = histogram(data1,
                  xtitle='some stochastic x_\mu^0',
                  c='red',
                  marker='o',
-                )
+)
 
 # pick the 16th bin and color it violet
 hst1.unpack(15).c('violet')
@@ -25,4 +25,4 @@ hst1 += Text3D('Highlight a\nspecial bin', pos=(0.5,20), c='v')
 hst2 = histogram(data2, format=hst1, alpha=0.5)
 
 # Show both:
-show(hst1, hst2)
\ No newline at end of file
+show(hst1, hst2, mode="image").close()
\ No newline at end of file
