@@ -10,8 +10,9 @@ plt2 = plot(x, cos(x), 'pr--', title='Plot2: y=cos(x)')
 plt3 = plot(x, sqrt(x),'Db-',  title='Plot3: y=sqrt(x)')
 plt4 = plot(x, sin(x), '*t--', title='Plot4: y=sin(x)')
 
+printc('plt1 is vtkAssembly?', isinstance(plt1, vtk.vtkAssembly))
+
 # window shape can be expressed as "n/m" or "n|m"
 show(plt1, plt2, plt3, plt4,
-     shape="3|1", sharecam=False, size=(1300,900), interactive=True)
+     shape="3|1", sharecam=False, size=(1300,900), interactive=True).close()
 
-printc('plt1 is vtkAssembly?', isinstance(plt1, vtk.vtkAssembly))
\ No newline at end of file
