@@ -9,6 +9,6 @@ pts2 = Grid(sx=1.2, sy=1.2).rotateZ(4).points()
 qp = quiver(pts1,       # points
             pts2-pts1,  # associated vectors
             c='r',
-           )
+)
 
-show(qp, __doc__, axes=1)
+show(qp, __doc__, axes=1).close()
