@@ -1,21 +1,18 @@
-"""
-Simple demo to illustrate the motion of a Big brownian
+"""Simple demo to illustrate the motion of a Big brownian
 particle in a swarm of small particles in 2D motion.
 The spheres collide elastically with themselves and
 with the walls of the box. The masses of the spheres
-are proportional to their radius**3 (as in 3D).
-"""
+are proportional to their radius**3 (as in 3D)"""
 # Adapted by M. Musy from E. Velasco (2009)
 print(__doc__)
 
-from vedo import Plotter, ProgressBar, dot
-from vedo import Grid, Sphere, Point
+from vedo import Plotter, ProgressBar, dot, Grid, Sphere, Point
 import random, numpy as np
 
 screen_w = 800
 screen_h = 800
 
-vp = Plotter(size=(screen_w, screen_h), axes=0, interactive=0)
+plt = Plotter(size=(screen_w, screen_h), axes=0, interactive=0)
 
 # Constants and time step
 Nsp = 200  # Number of small spheres
@@ -65,9 +62,9 @@ Spheres = [Sphere(pos=(Pos[0][0], Pos[0][1], 0), r=Radius[0], c="red", res=12).p
 for s in range(1, Nsp):
     a = Sphere(pos=(Pos[s][0], Pos[s][1], 0), r=Radius[s], c="blue", res=6).phong()
     Spheres.append(a)
-#    vp += a
-vp += Spheres
-vp += Grid(sx=screen_w, sy=screen_w)
+#    plt += a
+plt += Spheres
+plt += Grid(sx=screen_w, sy=screen_w)
 
 # Auxiliary variables
 Id = np.identity(Nsp)
@@ -136,8 +133,9 @@ for i in pb.range():
     if not int(i) % 10:  # every ten steps:
         rsp = [Pos[0][0], Pos[0][1], 0]
         rsv = [Vel[0][0], Vel[0][1], 0]
-        vp += Point(rsp, c="r", r=5, alpha=0.1)  # leave a point trace
-        vp.show()  # render scene
+        plt += Point(rsp, c="r", r=5, alpha=0.1)  # leave a point trace
+        plt.show()  # render scene
+        if plt.escaped: break
     pb.print()
 
-vp.show(interactive=1)
+plt.show(interactive=1).close()
