@@ -1,6 +1,6 @@
 """Simulation of the double slit experiment.
 (Any number of slits of any geometry can be added)
-Slit sources are placed on the plane shown as a thin grid."""
+Slit sources are placed on the plane shown as a thin grid"""
 # Can simulate the 'Arago spot', the bright point at the center of
 #  a circular object shadow (https://en.wikipedia.org/wiki/Arago_spot).
 import numpy as np
@@ -8,8 +8,8 @@ from vedo import *
 
 #########################################
 lambda1 = 680e-9  # red wavelength 680nm
-width = 10e-6  # slit width in m
-D = 0.1  # screen distance in m
+width = 10e-6     # slit width in m
+D = 0.1           # screen distance in m
 #########################################
 
 # create the slits as a set of individual coherent point-like sources
@@ -21,7 +21,7 @@ slits = slit1 + slit2
 # slits = [(cos(x)*4e-5, sin(x)*4e-5, 0) for x in arange(0,2*np.pi, .1)] # Arago spot
 # slits = Grid(sx=1e-4, sy=1e-4, resx=9, resy=9).points() # a square lattice
 
-vp = Plotter(title="The Double Slit Experiment", axes=9, bg="black")
+plt = Plotter(title="The Double Slit Experiment", axes=9, bg="black")
 
 screen = Grid(pos=[0, 0, -D], sx=0.1, sy=0.1, lw=0, resx=200, resy=50).wireframe(False)
 
@@ -40,11 +40,11 @@ for i, x in enumerate(screen_pts):
     screen_pts[i] = x + [0, 0, psi2 / norm]
 screen.points(screen_pts).cmap("hot", amplitudes)
 
-vp += [screen, __doc__]
-vp += Points(np.array(slits) * 200, c="w")  # slits scale magnified by factor 200
-vp += Grid(sx=0.1, sy=0.1, resx=6, resy=6, c="w", alpha=0.1)
-vp += Line([0, 0, 0], [0, 0, -D], c="w", alpha=0.1)
-vp += Text3D("source plane", pos=[-0.04, -0.05, 0], s=0.002, c="gray")
-vp += Text3D("detector plane D = "+str(D)+" m", pos=[-.04,-.05,-D+.001], s=.002, c="gray")
+plt += [screen, __doc__]
+plt += Points(np.array(slits) * 200, c="w")  # slits scale magnified by factor 200
+plt += Grid(sx=0.1, sy=0.1, resx=6, resy=6, c="w", alpha=0.1)
+plt += Line([0, 0, 0], [0, 0, -D], c="w", alpha=0.1)
+plt += Text3D("source plane", pos=[-0.04, -0.05, 0], s=0.002, c="gray")
+plt += Text3D("detector plane D = "+str(D)+" m", pos=[-.04,-.05,-D+.001], s=.002, c="gray")
 
-vp.show(zoom=1.1)
+plt.show(zoom=1.1).close()
