@@ -1,5 +1,5 @@
 """Forward kinematics: hover the mouse to drag the chain"""
-from vedo import Plotter, versor, Plane, Hyperboloid, Line
+from vedo import Plotter, versor, Plane, Line
 
 n = 15  # number of points
 l =  3  # length of one segment
@@ -12,7 +12,7 @@ def move(evt):
     for i in range(1, n):
         v = versor(coords[i] - coords[i-1])
         coords[i] = coords[i-1] + v * l
-    line.points(coords) # update positions
+    line.points(coords)  # update positions
     nodes.points(coords)
     plt.render()
 
@@ -20,9 +20,7 @@ plt = Plotter()
 plt.addCallback("mouse move", move)
 
 surf = Plane(sx=60, sy=60)
-#surf = Hyperboloid(c='b4').scale(15) # can be 3d too!
-
-line = Line([-l*n/2, 0], [l*n/2, 0], res=n, lw=12)
-nodes= line.clone().c('red3').pointSize(15).pickable(False)
+line = Line([l*n/2, 0], [-l*n/2, 0], res=n, lw=12)
+nodes= line.clone().c('red3').pointSize(15)
 
 plt.show(surf, line, nodes, __doc__, zoom=1.3).close()
