@@ -5,4 +5,4 @@ vol = Volume(dataurl+'head.vti')
 
 plt = IsosurfaceBrowser(vol, c='gold') # Plotter instance
 
-plt.show(axes=7, bg2='lb')
+plt.show(axes=7, bg2='lb').close()
