@@ -1,5 +1,5 @@
 """Custom color and transparency maps for Volumes"""
-from vedo import load, dataurl, show
+from vedo import Volume, dataurl, show
 from vedo.pyplot import cornerHistogram
 
 # Build a Volume object.
@@ -7,7 +7,7 @@ from vedo.pyplot import cornerHistogram
 # to define the transfer function in the range of the scalar.
 #  E.g.: setting alpha=[0, 0, 0, 1, 0, 0, 0] would make visible
 #  only voxels with value close to center of the range (see histogram).
-vol = load(dataurl+'embryo.slc') # returns a Volume
+vol = Volume(dataurl+'embryo.slc')
 vol.color([(0,"green"), (49,"green"),
            (50,"blue"), (109,"blue"),
            (110,"red"), (180,"red"),
@@ -20,4 +20,4 @@ vol.addScalarBar3D(title='color~\dot~alpha transfer function', c='k')
 ch = cornerHistogram(vol, logscale=True, pos='bottom-left')
 
 # show both Volume and Mesh
-show(vol, ch, __doc__, axes=1, zoom=1.2)
+show(vol, ch, __doc__, axes=1, zoom=1.2).close()
