@@ -10,11 +10,12 @@ npts = 500                       # nr. of points of known scalar value
 coords = np.random.rand(npts, 3) # range is [0, 1]
 scals = coords[:, 2]             # let the scalar be the z of the point itself
 
-apts = Points(coords).addPointArray(scals, name='scals')
+pts = Points(coords)
+pts.pointdata["scals"] = scals
 
 # Now interpolate these points to a full Volume
 # Available interpolation kernels are: shepard, gaussian, voronoi, linear.
-vol = interpolateToVolume(apts, kernel='shepard', radius=0.2, dims=(90,90,90))
+vol = interpolateToVolume(pts, kernel='shepard', radius=0.2, dims=(90,90,90))
 
 vol.c(["maroon","g","b"])        # set color   transfer function
 vol.alpha([0.3, 0.9])            # set opacity transfer function
@@ -30,4 +31,4 @@ ch = cornerHistogram(vol, pos="bottom-left")
 vol.addScalarBar3D(sy=1, title='Height is the voxel scalar')
 vol.scalarbar.rotateX(90).pos(1.15,1,0.5)
 
-show(apts, vol, ch, __doc__, axes=1, elevation=-90)
+show(pts, vol, ch, __doc__, axes=1, elevation=-90).close()
