@@ -1,11 +1,10 @@
 """Left: build a volume (grey) from a mesh where the
 foreground voxels are 1 and the background voxels are 0.
 
-Right: the Volume is isosurfaced.
-"""
+Right: the Volume is isosurfaced."""
 from vedo import *
 
-s = load(dataurl+"bunny.obj").normalize().wireframe()
+s = Mesh(dataurl+"bunny.obj").normalize().wireframe()
 
 v = mesh2Volume(s, spacing=(0.02, 0.02, 0.02)).alpha([0,0.5]).c('blue')
 
@@ -13,4 +12,4 @@ iso = v.isosurface().color("b")
 
 show(v, s.scale(1.05), __doc__, at=0, N=2)
 
-show(iso, at=1, interactive=1)
+show(iso, at=1, interactive=1).close()
