@@ -2,9 +2,9 @@
 
 mode=0, composite rendering
 mode=1, maximum-projection rendering"""
-from vedo import dataurl, load, show
+from vedo import dataurl, Volume, show
 
-vol1 = load(dataurl+"vase.vti")
+vol1 = Volume(dataurl+"vase.vti")
 
 # can set colors and transparencies along the scalar range
 # from minimum to maximum value. In this example voxels with
@@ -22,9 +22,9 @@ vol1.alphaGradient([0.0, 0.5, 0.9]).addScalarBar3D(title='composite shade', c='k
 vol1.scalarbar.scale(0.8).x(20)
 
 # mode = 1 is maximum-projection volume rendering
-vol2 = load(dataurl+"vase.vti").mode(1).shift(60,0,0)
+vol2 = Volume(dataurl+"vase.vti").mode(1).shift(60,0,0)
 vol2.addScalarBar3D(title='maximum-projection', c='k')
 vol2.scalarbar.scale(0.8).x(160)
 
 # show command creates and returns an instance of class Plotter
-show(vol1, vol2, __doc__, axes=1, size=(800,600))
+show(vol1, vol2, __doc__, size=(800,600), zoom=1.5).close()
