@@ -1,12 +1,15 @@
 """Read structured grid data and show
 the associated vector and scalar fields"""
-from vedo import load, dataurl, Arrows, show
+from vedo import *
+
+settings.useDepthPeeling = True
 
 g = load(dataurl+'structgrid.vts')
 
 coords = g.points()
+
 # g.print() gives the list of point and cell data contained in g
-vects  = g.getPointArray('Momentum')/600 
+vects  = g.pointdata['Momentum']/600 
 print('numpy array shapes are:', coords.shape, vects.shape)
 
 # build arrows from starting points to endpoints, with colormap
