@@ -20,7 +20,7 @@ stream = streamLines(ugrid, probe,
 # make a cloud of points form the ugrid, in order to draw arrows
 domain = pointCloudFrom(ugrid)
 coords = domain.points()
-vects  = domain.getPointArray('U')/200
+vects  = domain.pointdata['U']/200
 arrows = Arrows(coords-vects, coords+vects, c='jet_r') # use colormap
 box    = domain.box().c('k') # build a box frame of the domain
 
