@@ -10,7 +10,8 @@ windx = np.ones_like(x)*4
 windy = np.exp(-(x+18)**2/100) * np.sign(y)/(abs(y)+8)*20
 wind  = np.c_[windx, windy, np.zeros_like(windy)]
 
-g.addPointArray(wind, 'wind') # add the vectors to the mesh
+g.pointdata["wind"] = wind  # add the vectors to the mesh
+
 ars = Arrows(pts-wind/10, pts+wind/10, c='hot')
 
 ypr = np.linspace(-15,15, num=25)
