@@ -8,4 +8,4 @@ ug.cutWithPlane(origin=(5,0,1), normal=(1,1,5))
 
 msh = ug.tomesh(shrink=0.8) # return a polygonal Mesh
 
-show([(ug, __doc__), msh], N=2, axes=1, viewup='z')
+show([(ug, __doc__), msh], N=2, axes=1, viewup='z').close()
