@@ -5,7 +5,7 @@ v = Volume(dataurl+'vase.vti')
 
 pts = v.topoints().print() # returns Points
 
-scalars = pts.getPointArray(0)
+scalars = pts.pointdata[0]
 pts.cmap('afmhot_r', scalars)
 
 show([(v,__doc__), pts], N=2, viewup='z', axes=1).close()
\ No newline at end of file
