@@ -15,6 +15,7 @@ from vedo.version import _version as __version__
 from vedo.plotter import *
 from vedo.shapes import *
 from vedo.io import *
+from vedo.cli import execute_cli
 
 from vedo.base import *
 from vedo.ugrid import UGrid
@@ -33,7 +34,7 @@ import vedo.shapes as shapes
 from vedo.addons import Ruler, Goniometer, buildRulerAxes, Axes, Light, LegendBox
 
 import vedo.settings as settings
-from vedo.settings import datadir, dataurl, embedWindow
+from vedo.settings import dataurl, embedWindow
 
 # hack: need to uncomment this to generate dolfin documentation html
 from vedo.dolfin import _inputsort
@@ -46,12 +47,3 @@ from numpy import sin, cos, sqrt, exp, log, dot, cross, array
 settings._init()
 ###########################################################################
 
-
-################### deprecations
-def Text(*args, **kwargs):
-    print("*** Deprecation: use Text3D() instead of Text(). ***")
-    return Text3D(*args, **kwargs)
-
-def CubicGrid(*args, **kwargs):
-    print("*** CubicGrid is obsolete: use TessellatedBox. ***")
-    return TessellatedBox(*args, **kwargs)
