@@ -14,6 +14,7 @@ Colors definitions and printing methods.
 
 __all__ = [
     "printc",
+    "printd",
     "getColor",
     "getColorName",
     "colorMap",
@@ -24,19 +25,21 @@ __all__ = [
 _global_start_time = time.time()
 
 try:
-    import matplotlib
     import matplotlib.cm as cm_mpl
-    _has_matplotlib = cm_mpl
+    _has_matplotlib = True
 except:
     from vedo.cmaps import cmaps
     _has_matplotlib = False
     # see below, this is dealt with in colorMap()
 
-
+#########################################################
+# handy global shortcuts for terminal printing
+# Ex.: print(colors.red + "hello" + colors.reset)
+#########################################################
 red   = '\x1b[1m\x1b[31;1m'
 green = '\x1b[1m\x1b[32;1m'
-blue  = '\x1b[1m\x1b[34;1m'
 yellow= '\x1b[1m\x1b[33;1m'
+blue  = '\x1b[1m\x1b[34;1m'
 reset = "\x1b[0m"
 
 
@@ -53,7 +56,7 @@ colors = {
     "bisque": "#FFE4C4",
     "black": "#000000",
     "blanchedalmond": "#FFEBCD",
-    "blue": "#0000FF",
+    "blue": "#0f00fb", # "0000FF",
     "blueviolet": "#8A2BE2",
     "brown": "#A52A2A",
     "burlywood": "#DEB887",
@@ -95,7 +98,7 @@ colors = {
     "gold": "#FFD700",
     "goldenrod": "#DAA520",
     "gray": "#808080",
-    "green": "#008000",
+    "green": "#047f10", #"#008000",
     "greenyellow": "#ADFF2F",
     "honeydew": "#F0FFF0",
     "hotpink": "#FF69B4",
@@ -156,7 +159,7 @@ colors = {
     "powderblue": "#B0E0E6",
     "purple": "#800080",
     "rebeccapurple": "#663399",
-    "red": "#FF0000",
+    "red": "#fe1e1f", #"#FF0000",
     "rosybrown": "#BC8F8F",
     "royalblue": "#4169E1",
     "saddlebrown": "#8B4513",
@@ -182,7 +185,7 @@ colors = {
     "wheat": "#F5DEB3",
     "white": "#FFFFFF",
     "whitesmoke": "#F5F5F5",
-    "yellow": "#FFFF00",
+    "yellow": "#ffff36", #"#FFFF00",
     "yellowgreen": "#9ACD32",
 
     "blue9": "#a8cbfe",      # bootstrap5 colors
@@ -452,6 +455,84 @@ cmaps_names = (
     "viridis",   "viridis_r",   "winter",     "winter_r"
 )
 
+
+# default sets of colors
+colors1 = [
+    [1.0, 0.832, 0.000],  # gold
+    [0.960, 0.509, 0.188],
+    [0.901, 0.098, 0.194],
+    [0.235, 0.85, 0.294],
+    [0.46, 0.48, 0.000],
+    [0.274, 0.941, 0.941],
+    [0.0, 0.509, 0.784],
+    [0.1, 0.1, 0.900],
+    [0.902, 0.7, 1.000],
+    [0.941, 0.196, 0.901],
+]
+# negative integer color number get this:
+colors2 = [
+    (0.99, 0.83, 0),    # gold
+    (0.59, 0.0, 0.09),  # dark red
+    (0.5, 1.0, 0.0),    # green
+    (0.5, 0.5, 0),      # yellow-green
+    (0.0, 0.66, 0.42),  # green blue
+    (0.0, 0.18, 0.65),  # blue
+    (0.4, 0.0, 0.4),    # plum
+    (0.4, 0.0, 0.6),
+    (0.2, 0.4, 0.6),
+    (0.1, 0.3, 0.2),
+]
+
+
+emoji = {
+    "\bomb": u"\U0001F4A5",
+    "\sparks": u"\U00002728",
+    "\ethumbup": u"\U0001F44d",
+    "\etarget": u"\U0001F3af",
+    "\save": u"\U0001F4be",
+    "\noentry": u"\U000026d4",
+    "\video": u"\U0001F4fd ",
+    "\lightning": u"\U000026a1",
+    "\camera": u"\U0001F4f8",
+    "\!?": u"\U00002049",
+    "\times": u"\U0000274c",
+    "\world": u"\U0001F30d",
+    "\erainbow": u"\U0001F308",
+    "\idea": u"\U0001F4a1",
+    "\pin": u"\U0001F4CC",
+    "\construction": u"\U0001F6A7",
+    "\rightarrow": u"\U000027a1",
+    "\minus": u"\U00002796",
+    "\erocket": u"\U0001F680",
+    "\hourglass": u"\U000023f3",
+    "\prohibited": u"\U0001F6ab",
+    "\checked": u"\U00002705",
+    "\smile": u"\U0001F642",
+    "\sad": u"\U0001F612",
+    "\star": u"\U00002B50",
+    "\zzz": u"\U0001F4a4",
+    "\mu": u"\U000003BC",
+    "\pi": u"\U000003C0",
+    "\sigma": u"\U000003C3",
+}
+
+# terminal color print
+def _has_colors(stream):
+    if not hasattr(stream, "isatty"):
+        return False
+    if not stream.isatty():
+        return False
+    try:
+        import curses
+
+        curses.setupterm()
+        return curses.tigetnum("colors") > 2
+    except:
+        return False
+
+_terminal_has_colors = _has_colors(sys.stdout)
+
+
 def _isSequence(arg):
     # Check if input is iterable.
     if hasattr(arg, "strip"):
@@ -462,7 +543,6 @@ def _isSequence(arg):
         return True
     return False
 
-
 def getColor(rgb=None, hsv=None):
     """
     Convert a color or list of colors to (r,g,b) format from many different input formats.
@@ -488,6 +568,14 @@ def getColor(rgb=None, hsv=None):
             seqcol.append(getColor(sc))
         return seqcol
 
+    # because they are most common:
+    if rgb=='r':
+        return (0.9960784313725, 0.11764705882352, 0.121568627450980)
+    elif rgb=='g':
+        return (0.0156862745098, 0.49803921568627, 0.062745098039215)
+    elif rgb=='b':
+        return (0.0588235294117, 0.0,              0.984313725490196)
+
     if str(rgb).isdigit():
         rgb = int(rgb)
 
@@ -532,8 +620,7 @@ def getColor(rgb=None, hsv=None):
             namedColors = vtk.vtkNamedColors()
             rgba = [0, 0, 0, 0]
             namedColors.GetColor(c, rgba)
-            return list(np.array(rgba[0:3]) / 255.0)
-
+            return (rgba[0]/255.0, rgba[1]/255.0, rgba[2]/255.0)
 
     elif isinstance(c, int):  # color number
         if c >= 0:
@@ -550,7 +637,6 @@ def getColor(rgb=None, hsv=None):
     # print("Unknown color:", c)
     return (0.5, 0.5, 0.5)
 
-
 def getColorName(c):
     """
     Find the name of a color.
@@ -608,9 +694,10 @@ def colorMap(value, name="jet", vmin=None, vmax=None):
 
         .. image:: https://matplotlib.org/1.2.1/_images/show_colormaps.png
 
-    .. tip:: Can also use directly a matplotlib color map:
+    .. tip:: Can also directly use and customize a matplotlib color map:
 
         :Example:
+
             .. code-block:: python
 
                 from vedo import colorMap
@@ -619,70 +706,63 @@ def colorMap(value, name="jet", vmin=None, vmax=None):
 
                 (1.0, 0.809016994374948, 0.6173258487801733)
     """
-    value_isSequence = False
-    if _isSequence(value):
-        value_isSequence = True
-        values = np.array(value)
-        if vmin is None:
-            vmin = np.min(values)
-        if vmax is None:
-            vmax = np.max(values)
+    cut = _isSequence(value) # to speed up later
+
+    if cut:
+        values = np.asarray(value)
+        if vmin is None: vmin = np.min(values)
+        if vmax is None: vmax = np.max(values)
         values = np.clip(values, vmin, vmax)
-        values -= vmin
-        values = values / (vmax - vmin)
-
-    # matplotlib not available #######################
-    if not _has_matplotlib:
-        invert=False
-        if name.endswith('_r'):
-            invert=True
-            name = name.replace('_r', "")
-        cmap = cmaps[name]
-
-        n = len(cmap)-1
-        if value_isSequence:
-            outs = []
-            for v in values:
-                iv = min(255, int(v*n))
-                if invert:
-                    rgb = hex2rgb(cmap[n-iv])
-                else:
-                    rgb = hex2rgb(cmap[iv])
-                outs.append(rgb)
-            return outs
+        values = (values - vmin) / (vmax - vmin)
+    else:
+        if vmin is None:
+            printc("In colorMap(): must specify vmin! Assume 0.0", c='r')
+            vmin = 0
+        if vmax is None:
+            printc("In colorMap(): must specify vmax! Assume 1.0", c='r')
+            vmax = 1
+        values = [(value - vmin) / (vmax - vmin)]
 
+    if _has_matplotlib:
+        # matplotlib is available, use it! ###########################
+        if isinstance(name, str):
+            mp = cm_mpl.get_cmap(name=name)
         else:
-            iv = min(255, int(value*n))
-            if invert:
-                return hex2rgb(cmap[n-iv])
-            else:
-                return hex2rgb(cmap[iv])
+            mp = name  # assume matplotlib.colors.LinearSegmentedColormap
+        result = mp(values)[:, [0,1,2]]
 
-    # matplotlib is available, use it! #######################
-    if isinstance(name, matplotlib.colors.LinearSegmentedColormap):
-        mp = name
     else:
-        mp = cm_mpl.get_cmap(name=name)
+        # matplotlib not available ###################################
+        invert = False
+        if name.endswith('_r'):
+            invert = True
+            name = name.replace('_r', "")
+        try:
+            cmap = cmaps[name]
+        except KeyError:
+            printc("In colorMap(): no color map with name:", name, 'or', name+'_r', c='r')
+            printc("Available color maps are:\n", cmaps.keys(), c='y', bold=False)
+            return np.array([0.5,0.5,0.5])
 
-    if value_isSequence:
-        mp = cm_mpl.get_cmap(name=name)
-        return mp(values)[:,[0,1,2]]
+        result = []
+        n = len(cmap)-1
+        for v in values:
+            iv = int( v * n )
+            if invert: iv = n - iv
+            rgb = hex2rgb(cmap[iv])
+            result.append(rgb)
+        result = np.array(result)
+
+    if cut:
+        return result
     else:
-        value -= vmin
-        dv = vmax - vmin
-        if dv:
-            value /= dv
-        if value > 0.999:
-            value = 0.999
-        elif value < 0:
-            value = 0
-        return mp(value)[0:3]
+        return result[0]
 
 
 def buildPalette(color1, color2, N, hsv=True):
     """
     Generate N colors starting from `color1` to `color2`
-    by linear interpolation HSV in or RGB spaces.
+    by linear interpolation in HSV or RGB spaces.
 
     :param int N: number of output colors.
     :param color1: first rgb color.
@@ -706,10 +786,10 @@ def buildPalette(color1, color2, N, hsv=True):
 
 
 def buildLUT(colorlist,
-            vmin=None, vmax=None,
-            belowColor=None, aboveColor=None, nanColor=None,
-            belowAlpha=1, aboveAlpha=1, nanAlpha=1,
-            interpolate=False,
+             vmin=None, vmax=None,
+             belowColor=None, aboveColor=None, nanColor=None,
+             belowAlpha=1, aboveAlpha=1, nanAlpha=1,
+             interpolate=False,
     ):
     """
     Generate colors in a lookup table (LUT).
@@ -794,83 +874,7 @@ def buildLUT(colorlist,
     lut.Build()
     return lut
 
-
-# default sets of colors
-colors1 = [
-    [1.0, 0.832, 0.000],  # gold
-    [0.960, 0.509, 0.188],
-    [0.901, 0.098, 0.194],
-    [0.235, 0.85, 0.294],
-    [0.46, 0.48, 0.000],
-    [0.274, 0.941, 0.941],
-    [0.0, 0.509, 0.784],
-    [0.1, 0.1, 0.900],
-    [0.902, 0.7, 1.000],
-    [0.941, 0.196, 0.901],
-]
-# negative integer color number get this:
-colors2 = [
-    (0.99, 0.83, 0),  # gold
-    (0.59, 0.0, 0.09),  # dark red
-    (0.5, 1.0, 0.0),  # green
-    (0.5, 0.5, 0),  # yellow-green
-    (0.0, 0.66, 0.42),  # green blue
-    (0.0, 0.18, 0.65),  # blue
-    (0.4, 0.0, 0.4),  # plum
-    (0.4, 0.0, 0.6),
-    (0.2, 0.4, 0.6),
-    (0.1, 0.3, 0.2),
-]
-
-
-# terminal color print
-def _has_colors(stream):
-    if not hasattr(stream, "isatty"):
-        return False
-    if not stream.isatty():
-        return False
-    try:
-        import curses
-
-        curses.setupterm()
-        return curses.tigetnum("colors") > 2
-    except:
-        return False
-
-_terminal_has_colors = _has_colors(sys.stdout)
-
-emoji = {
-    "\bomb": u"\U0001F4A5",
-    "\sparks": u"\U00002728",
-    "\ethumbup": u"\U0001F44d",
-    "\etarget": u"\U0001F3af",
-    "\save": u"\U0001F4be",
-    "\noentry": u"\U000026d4",
-    "\video": u"\U0001F4fd ",
-    "\lightning": u"\U000026a1",
-    "\camera": u"\U0001F4f8",
-    "\!?": u"\U00002049",
-    "\times": u"\U0000274c",
-    "\world": u"\U0001F30d",
-    "\erainbow": u"\U0001F308",
-    "\idea": u"\U0001F4a1",
-    "\pin": u"\U0001F4CC",
-    "\construction": u"\U0001F6A7",
-    "\rightarrow": u"\U000027a1",
-    "\minus": u"\U00002796",
-    "\erocket": u"\U0001F680",
-    "\hourglass": u"\U000023f3",
-    "\prohibited": u"\U0001F6ab",
-    "\checked": u"\U00002705",
-    "\smile": u"\U0001F642",
-    "\sad": u"\U0001F612",
-    "\star": u"\U00002B50",
-    "\zzz": u"\U0001F4a4",
-    "\mu": u"\U000003BC",
-    "\pi": u"\U000003C0",
-    "\sigma": u"\U000003C3",
-}
-
+#########################################################################
 def printc(*strings,
             c = None,
             bc = None,
@@ -882,7 +886,6 @@ def printc(*strings,
             dim = False,
             invert = False,
             box = "",
-            dbg = False,
             end = "\n",
             flush = True,
     ):
@@ -901,7 +904,6 @@ def printc(*strings,
     :param box: print a box with specified text character ['']
     :param bool flush: flush buffer after printing [True]
     :param str end: the end character to be printed [newline]
-    :param bool dbg: print debug information about the evironment
 
     :Example:
         .. code-block:: python
@@ -944,7 +946,7 @@ def printc(*strings,
 
             txt += str(s) + separator
 
-        special, cseq, reset = "", "", u"\u001b[0m"
+        special, cseq = "", ""
         oneletter_colors = {'k': u'\u001b[30;1m', # because these are supported by most terminals
                             'r': u'\u001b[31;1m',
                             'g': u'\u001b[32;1m',
@@ -1015,45 +1017,7 @@ def printc(*strings,
         else:
 
             out = special + cseq + txt + reset
-
-            if dbg:
-                from inspect import currentframe, getframeinfo
-                from vedo.utils import isSequence, precision
-                cf = currentframe().f_back
-                cfi = getframeinfo(cf)
-                fname = os.path.basename(getframeinfo(cf).filename)
-                print("\x1b[7m\x1b[3m\x1b[37m"+fname+" line:\x1b[1m"+str(cfi.lineno)+reset, end='')
-                print('\x1b[3m\x1b[37m\x1b[2m', "\U00002501"*30, time.ctime(), reset)
-                if txt:
-                    print("    \x1b[37m\x1b[1mMessage : "+ out)
-                print("    \x1b[37m\x1b[1mFunction:\x1b[0m\x1b[37m "+ str(cfi.function))
-                print('    \x1b[1mLocals  :'+reset)
-                for loc in cf.f_locals.keys():
-                    obj = cf.f_locals[loc]
-                    var = repr(obj)
-                    if 'module ' in var: continue
-                    if 'function ' in var: continue
-                    if 'class ' in var: continue
-                    if '_' in loc: continue
-                    if hasattr(obj, 'name'):
-                        if not obj.name:
-                            oname = str(type(obj))
-                        else:
-                            oname = obj.name
-                        var = oname + ', at ' + precision(obj.GetPosition(),3)
-
-                    print('      \x1b[37m', loc,'=', var[:60].replace('\n',''), reset)
-                    if isSequence(obj) and len(obj)>4:
-                        print('           \x1b[37m\x1b[2m\x1b[3m len:', len(obj),
-                              ' min:', precision(min(obj), 4),
-                              ' max:', precision(max(obj), 4),
-                              reset)
-
-                print("    \x1b[1m\x1b[37mElapsed time:\x1b[0m\x1b[37m",
-                      str(time.time()-_global_start_time)[:6], 's'+reset)
-
-            else:
-                sys.stdout.write(out + end)
+            sys.stdout.write(out + end)
 
     except: # ------------------------------------------------------------- fallback
         print(*strings, end=end)
@@ -1061,6 +1025,58 @@ def printc(*strings,
     if flush:
         sys.stdout.flush()
 
+def printd(*strings, q=False):
+    """
+    Print debug information about the evironment where the printd() is called.
+    Local variables are printed out with their current values.
+
+    :param bool q: quit (exit) python session after the printd call.
+    """
+    from inspect import currentframe, getframeinfo
+    from vedo.utils import isSequence, precision
+
+    cf = currentframe().f_back
+    cfi = getframeinfo(cf)
+
+    fname = os.path.basename(getframeinfo(cf).filename)
+    print("\x1b[7m\x1b[3m\x1b[37m"+fname+" line:\x1b[1m"+str(cfi.lineno)+reset, end='')
+    print('\x1b[3m\x1b[37m\x1b[2m', "\U00002501"*30, time.ctime(), reset)
+    if len(strings):
+        print("    \x1b[37m\x1b[1mMessage : ", *strings)
+    print("    \x1b[37m\x1b[1mFunction:\x1b[0m\x1b[37m "+ str(cfi.function))
+    print('    \x1b[1mLocals  :'+reset)
+    for loc in cf.f_locals.keys():
+        obj = cf.f_locals[loc]
+        var = repr(obj)
+        if 'module ' in var: continue
+        if 'function ' in var: continue
+        if 'class ' in var: continue
+        if loc.startswith('_'): continue
+        if hasattr(obj, 'name'):
+            if not obj.name:
+                oname = str(type(obj))
+            else:
+                oname = obj.name
+            var = oname + ', at ' + precision(obj.GetPosition(),3)
+
+        var = var.replace('vtkmodules.','')
+        print('      \x1b[37m', loc,'\t\t=', var[:60].replace('\n',''), reset)
+        if isSequence(obj) and len(obj)>4:
+            try:
+                print('           \x1b[37m\x1b[2m\x1b[3m len:', len(obj),
+                      ' min:', precision(min(obj), 4),
+                      ' max:', precision(max(obj), 4),
+                      reset)
+            except:
+                pass
+
+    print("    \x1b[1m\x1b[37mElapsed time:\x1b[0m\x1b[37m",
+          str(time.time()-_global_start_time)[:6], 's'+reset)
+    if q:
+        print(f"    \x1b[1m\x1b[37mExiting python now (q={bool(q)}).\x1b[0m\x1b[37m")
+        exit(0)
+    sys.stdout.flush()
+
 
 def colorPicker(xy, plotter=None):
     """Pick color of specific (x,y) pixel on the screen."""
