@@ -66,42 +66,129 @@ def tips():
 ####################################################################################
 # example web page for X3D
 x3d_html = """
-<html>
+<!DOCTYPE html>
+<html lang="en">
 <head>
-    <title> My X3DOM web page </title>
-    <script type='text/javascript' src='https://www.x3dom.org/download/x3dom.js'> </script>
-    <link rel='stylesheet' type='text/css' href='https://www.x3dom.org/download/x3dom.css'/>
+  <meta charset="UTF-8">
+  <meta name="viewport" content="width=device-width, initial-scale=1.0">
+  <title> vedo with x3d </title>
+
+  <!-- THESE ARE THE RELEVANT LINES: -->
+  <script src='https://www.x3dom.org/download/x3dom.js'> </script>
+  <link rel='stylesheet' type='text/css' href='https://www.x3dom.org/download/x3dom.css'/>
+
+  <style>
+     table, td, th { border: 1px solid black; background-color: powderblue;}
+     table {width: 70%; border-collapse: collapse;}
+     table th {width: 35%;}
+  </style>
 </head>
-<body><font face="Verdana" size="3">
 
-<h1>My x3d rendering web page</h1>
-<p>
-    This example loads a 3D scene from file ~fileoutput generated by
-    <a href="https://github.com/marcomusy/vedo">vedo</a>
-    (see e.g. <a href="https://github.com/marcomusy/vedo/tree/master/examples/other/export_x3d.py">export_x3d.py</a>).
+<body style="font-family: Verdana">
+  <h1>Example html generated by vedo</h1>
+  This example loads a 3D scene from file ~fileoutput generated by
+  <a href="https://github.com/marcomusy/vedo">vedo</a>
+  (see <a href="https://github.com/marcomusy/vedo/tree/master/examples/other/export_x3d.py">export_x3d.py</a>).
+  <br><br>
 
-    <br/>
-    <br/> - Press t to reset viewpoint.
-    <br/> - Press i to reset camera distance.
-    <br/> - Right-click and drag mouse to zoom.
-    <br/> - Middle-click and drag mouse to pan.
-</p>
 
-<x3d width='~widthpx' height='~heightpx'>
-    <scene>
-        <Inline url="~fileoutput" />
-    </scene>
-</x3d>
+  <!-- THESE ARE THE RELEVANT LINES: -->
+  <x3d width='~widthpx' height='~heightpx'>
+     <scene>
+        <Inline url="~fileoutput"> </Inline>
+     </scene>
+  </x3d>
 
-<br clear="all">
-<br/>PS: This should work with Firefox/IE.
-With Chrome, webgl might not be active by default, then try:<br/><i>
-google-chrome --enable-webgl --use-gl=desktop
---log-level=0 --allow-file-access-from-files --allow-file-access ~fileoutput
-</i>
-</font></body>
+  <h3>Nothing shows up above this line?</h3>
+  Enable your browser to load local files:
+  <br><b>Firefox</b>: type <code>about:config</code> in the URL bar and
+  change <code>privacy.file_unique_origin</code> from <code>True</code> to <code>False</code>
+  <br><b>Chrome</b>: from terminal type:
+  <code>google-chrome --enable-webgl --allow-file-access-from-files</code>
+  (see <a href="https://cmatskas.com/interacting-with-local-data-files-using-chrome/">here</a>)
+
+  <br>
+  <h3>Controls:</h3>
+  <h4><strong>Examine Mode (activate with key 'e'):</strong></h4>
+  <table>
+     <tbody>
+        <tr class="even description">
+           <th>Button</th>
+           <th>Function</th>
+        </tr>
+        <tr>
+           <td>Left Button / Left Button + Shift</td>
+           <td>Rotate</td>
+        </tr>
+        <tr>
+           <td>Mid Button / Left Button + Ctl</td>
+           <td>Pan</td>
+        </tr>
+        <tr>
+           <td>Right Button / Wheel / Left Button + Alt</td>
+           <td>Zoom</td>
+        </tr>
+        <tr>
+           <td>Left double click</td>
+           <td>Set center of rotation</td>
+        </tr>
+     </tbody>
+  </table>
+  <h4><strong>Walk Mode (activate with key 'w'):</strong></h4>
+  <table>
+     <tbody>
+        <tr class="even description">
+           <th>Button</th>
+           <th>Function</th>
+        </tr>
+        <tr>
+           <td>Left Button</td>
+           <td>Move forward</td>
+        </tr>
+        <tr>
+           <td>Right Button</td>
+           <td>Move backward</td>
+        </tr>
+     </tbody>
+  </table>
+  <h4><strong>Fly Mode (activate with key 'f'):</strong></h4>
+  <table>
+     <tbody>
+        <tr class="even description">
+           <th>Button</th>
+           <th>Function</th>
+        </tr>
+        <tr>
+           <td>Left Button</td>
+           <td>Move forward</td>
+        </tr>
+        <tr>
+           <td>Right Button</td>
+           <td>Move backward</td>
+        </tr>
+     </tbody>
+  </table>
+  <h3>Non-interactive camera movement</h3>
+  <table>
+     <tbody>
+        <tr class="even description">
+           <th>Key</th>
+           <th>Function</th>
+        </tr>
+        <tr>
+           <td>r</td>
+           <td>reset view</td>
+        </tr>
+        <tr>
+           <td>a</td>
+           <td>show all</td>
+        </tr>
+        <tr>
+           <td>u</td>
+           <td>upright</td>
+        </tr>
+     </tbody>
+  </table>
+</body>
 </html>
 """
-
-
-####################################################################################
