@@ -1456,24 +1456,59 @@ def exportWindow(fileoutput, binary=False):
         else:
             np.save(fileoutput, [sdict])
 
-    ####################################################################
-    # elif fr.endswith(".obj"):
-    #     w = vtk.vtkOBJExporter()
-    #     w.SetInputData(settings.plotter_instance.window)
-    #     w.Update()
-    #     colors.printc("\save Saved file:", fileoutput, c="g")
-
-
     ####################################################################
     elif fr.endswith(".x3d"):
         from vedo.docs import x3d_html
+
+        obj = list(set(settings.plotter_instance.getMeshes()+
+                       settings.plotter_instance.actors))
+        if len(settings.plotter_instance.axes_instances):
+            obj.append(settings.plotter_instance.axes_instances[0])
+        for a in obj:
+            if isinstance(a, Mesh):
+                newa = a.clone(transformed=True)
+                settings.plotter_instance.remove(a, render=False).add(newa, render=False)
+
+            elif isinstance(a, Assembly):
+                for b in a.unpack():
+                    if b:
+                        newb = b.clone(transformed=True)
+                        settings.plotter_instance.add(newb, render=False)
+                settings.plotter_instance.remove(a)
+        settings.plotter_instance.render()
+
         exporter = vtk.vtkX3DExporter()
         exporter.SetBinary(binary)
         exporter.FastestOff()
         exporter.SetInput(settings.plotter_instance.window)
         exporter.SetFileName(fileoutput)
+#        exporter.WriteToOutputStringOn() # see below
         exporter.Update()
         exporter.Write()
+
+# this can reduce the size by more than half...
+#        outstring = exporter.GetOutputString().decode("utf-8") # this fails though
+#        from vedo.utils import isInteger, isNumber, precision
+#        newlines = []
+#        for l in outstring.splitlines(True):
+#            ls = l.lstrip()
+#            content = ls.split()
+#            newls = ""
+#            for c in content:
+#                c2 = c.replace(',','')
+#                if isNumber(c2) and not isInteger(c2):
+#                    newc = precision(float(c2), 4)
+#                    if ',' in c:
+#                        newls += newc + ','
+#                    else:
+#                        newls += newc + ' '
+#                else:
+#                    newls += c + ' '
+#        newlines.append(newls.lstrip()+'\n')
+#        with open("fileoutput", 'w') as f:
+#            l = "".join(newlines)
+#            f.write(l)
+
         x3d_html = x3d_html.replace("~fileoutput", fileoutput)
         wsize = settings.plotter_instance.window.GetSize()
         x3d_html = x3d_html.replace("~width", str(wsize[0]))
@@ -1500,7 +1535,7 @@ def exportWindow(fileoutput, binary=False):
     else:
         colors.printc("Export extension", fr.split('.')[-1],
                       "is not supported.", c='r')
-    return
+    return settings.plotter_instance
 
 
 def importWindow(fileinput, mtlFile=None, texturePath=None):
