@@ -48,7 +48,8 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
                     varb.SetName("RGBA")
                     imgb = vtk.vtkImageData()
                     imgb.SetDimensions(obj.shape[1], obj.shape[0], 1)
-                    imgb.GetPointData().SetScalars(varb)
+                    imgb.GetPointData().AddArray(varb)
+                    imgb.GetPointData().SetActiveScalars("RGBA")
                     iac.AddInputData(imgb)
                 iac.Update()
                 img = iac.GetOutput()
@@ -62,7 +63,8 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
                 varb.SetName("RGBA")
                 img = vtk.vtkImageData()
                 img.SetDimensions(obj.shape[1], obj.shape[0], 1)
-                img.GetPointData().SetScalars(varb)
+                img.GetPointData().AddArray(varb)
+                img.GetPointData().SetActiveScalars("RGBA")
 
         elif isinstance(obj, vtk.vtkImageData):
             img = obj
@@ -71,14 +73,16 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             if "https://" in obj:
                 obj = vedo.io.download(obj, verbose=False)
 
-            if   ".png" in obj.lower():
+            fname = obj.lower()
+            if fname.endswith(".png"):
                 picr = vtk.vtkPNGReader()
-            elif ".jpg" in obj.lower() or ".jpeg" in obj.lower():
+            elif fname.endswith(".jpg") or fname.endswith(".jpeg"):
                 picr = vtk.vtkJPEGReader()
-            elif ".bmp" in obj.lower():
+            elif fname.endswith(".bmp"):
                 picr = vtk.vtkBMPReader()
-            elif ".tif" in obj.lower():
+            elif fname.endswith(".tif") or fname.endswith(".tiff"):
                 picr = vtk.vtkTIFFReader()
+                picr.SetOrientationType(vedo.settings.tiffOrientationType)
             else:
                 colors.printc("Cannot understand picture format", obj, c='r')
                 return
@@ -142,6 +146,17 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             pic.SetPosition(self.GetPosition())
         return pic
 
+    def extent(self, ext=None):
+        """
+        Get or set the physical extent that the picture spans.
+        Format is ext=[minx, maxx, miny, maxy].
+        """
+        if ext is None:
+            return self._data.GetExtent()
+        self._data.SetExtent(ext[0],ext[1],ext[2],ext[3],0,0)
+        self._mapper.Modified()
+        return self
+    
     def text(self, txt,
                    pos=(0,0,0),
                    s=1,
@@ -267,7 +282,8 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
     def pad(self, pixels=10, value=255):
         """
         Add the specified number of pixels at the picture borders.
-
+        Pixels can be a list formatted as [left,right,bottom,top].
+        
         Parameters
         ----------
         pixels : int,list , optional
@@ -281,7 +297,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         pf.SetConstant(value)
         if utils.isSequence(pixels):
             pf.SetOutputWholeExtent(x0-pixels[0],x1+pixels[1],
-                                    y0-pixels[2],y1+pixels[4], 0,0)
+                                    y0-pixels[2],y1+pixels[3], 0,0)
         else:
             pf.SetOutputWholeExtent(x0-pixels,x1+pixels, y0-pixels,y1+pixels, 0,0)
         pf.Update()
@@ -311,14 +327,59 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         return Picture(constantPad.GetOutput())
 
 
+    def append(self, pictures, axis='z', preserveExtents=False):
+        """
+        Append the input images to the current one along the specified axis.
+        Except for the append axis, all inputs must have the same extent.
+        All inputs must have the same number of scalar components.
+        The output has the same origin and spacing as the first input.
+        The origin and spacing of all other inputs are ignored.
+        All inputs must have the same scalar type.
+
+        :param int,str axis: axis expanded to hold the multiple images.
+        :param bool preserveExtents: if True, the extent of the inputs is used to place
+            the image in the output. The whole extent of the output is the union of the input
+            whole extents. Any portion of the output not covered by the inputs is set to zero.
+            The origin and spacing is taken from the first input.
+
+        .. code-block:: python
+
+            from vedo import Picture, dataurl
+            pic = Picture(dataurl+'dog.jpg').pad()
+            pic.append([pic,pic,pic], axis='y')
+            pic.append([pic,pic,pic,pic], axis='x')
+            pic.show(axes=1)
+        """
+        ima = vtk.vtkImageAppend()
+        ima.SetInputData(self._data)
+        if not utils.isSequence(pictures):
+            pictures = [pictures]
+        for p in pictures:
+            if isinstance(p, vtk.vtkImageData):
+                ima.AddInputData(p)
+            else:
+                ima.AddInputData(p._data)
+        ima.SetPreserveExtents(preserveExtents)
+        if axis   == "x":
+            axis = 0
+        elif axis == "y":
+            axis = 1
+        ima.SetAppendAxis(axis)
+        ima.Update()
+        return self._update(ima.GetOutput())
+    
+
     def resize(self, newsize):
         """Resize the image resolution by specifying the number of pixels in width and height.
         If left to zero, it will be automatically calculated to keep the original aspect ratio.
 
-        :param list newsize: shape of picture as [npx, npy]
+        :param list,float newsize: shape of picture as [npx, npy], or as a fraction.
         """
         old_dims = np.array(self._data.GetDimensions())
 
+        if not utils.isSequence(newsize):
+            newsize = (old_dims * newsize + 0.5).astype(int)
+
         if not newsize[1]:
             ar = old_dims[1]/old_dims[0]
             newsize = [newsize[0], int(newsize[0]*ar+0.5)]
@@ -349,59 +410,48 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
             raise RuntimeError()
         ff.Update()
         return self._update(ff.GetOutput())
-        
-    def rotateAntiClockWise(self, n=1):
+    
+    def rotate(self, angle, center=(), scale=1, mirroring=False, bc='w', alpha=1):
         """
-        Rotate a black and white Picture in steps of 90 degrees anticlockwise 
-        (landscape to portrait and viceversa).
+        Rotate an image by an angle (anticlockwise).
 
         Parameters
         ----------
-        n : int, optional
-            number of 90 deg rotations. The default is 1.
-        """
-        nx,ny,nz = self._data.GetDimensions()
-        n = n%4
-        if n==1:
-            self.bw()
-            varr = self._data.GetPointData().GetScalars()
-            arr = utils.vtk2numpy(varr).reshape(nx,ny, order='F')
-            pp = Picture(arr).mirror('x')
-            img = pp._data
-            pp = None
-            return self._update(img)
-        elif n==2:
-            return self.mirror('x').mirror('y')
-        elif n==3:
-            self.bw()
-            varr = self._data.GetPointData().GetScalars()
-            arr = utils.vtk2numpy(varr).reshape(nx,ny, order='F')
-            pp = Picture(arr).mirror('y')
-            img = pp._data
-            pp = None
-            return self._update(img)
+        angle : float
+            rotation angle in degrees.
+        center: list
+            center of rotation (x,y) in pixels.
+        """        
+        bounds = self.bounds()
+        pc = [0,0,0]
+        if center:
+            pc[0] = center[0]
+            pc[1] = center[1]
         else:
-            return self
+            pc[0] = (bounds[1] + bounds[0]) / 2.0
+            pc[1] = (bounds[3] + bounds[2]) / 2.0
+        pc[2] = (bounds[5] + bounds[4]) / 2.0
+  
+        transform = vtk.vtkTransform()
+        transform.Translate(pc)
+        transform.RotateWXYZ(-angle, 0, 0, 1)
+        transform.Scale(1/scale,1/scale,1)
+        transform.Translate(-pc[0], -pc[1], -pc[2])
 
-    # def rotateACW(self, n=1):
-    #     """
-    #     Rotate a black and white Picture in steps of 90 degrees anticlockwise 
-    #     (landscape to portrait and viceversa).
+        reslice = vtk.vtkImageReslice()
+        reslice.SetMirror(mirroring)
+        c = np.array(colors.getColor(bc))*255
+        reslice.SetBackgroundColor([c[0],c[1],c[2], alpha*255])
+        reslice.SetInputData(self._data)
+        reslice.SetResliceTransform(transform)
+        reslice.SetOutputDimensionality(2)
+        reslice.SetInterpolationModeToCubic()
+        reslice.SetOutputSpacing(self._data.GetSpacing())
+        reslice.SetOutputOrigin(self._data.GetOrigin())
+        reslice.SetOutputExtent(self._data.GetExtent())
+        reslice.Update()
+        return self._update(reslice.GetOutput())
 
-    #     Parameters
-    #     ----------
-    #     n : int, optional
-    #         number of 90 deg rotations. The default is 1.
-    #     """
-    #     irs = vtk.vtkImageResize()
-    #     irs.SetResizeMethodToOutputDimensions()
-    #     nx,ny,nz = self._data.GetDimensions()
-    #     irs.SetOutputDimensions(ny, int(nx/2), 1)
-    #     irs.SetInputData(self._data)
-    #     irs.Update()
-    #     return self._update(irs.GetOutput())
-       
-        
     def select(self, component):
         """Select one single component of the rgb image"""
         ec = vtk.vtkImageExtractComponents()
@@ -465,6 +515,46 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         medf.SetInputData(self._data)
         medf.Update()        
         return self._update(medf.GetOutput())
+    
+    def enhance(self):
+        """
+        Enhance a b&w picture using the laplacian, enhancing high-freq edges.
+        
+        Example:
+            
+            .. code-block:: python
+            
+                import vedo
+                p = vedo.Picture(vedo.dataurl+'images/dog.jpg').bw()
+                vedo.show(p, p.clone().enhance(), N=2, mode='image')
+        """       
+        img = self._data
+        scalarRange = img.GetPointData().GetScalars().GetRange()
+        
+        cast = vtk.vtkImageCast()
+        cast.SetInputData(img)
+        cast.SetOutputScalarTypeToDouble()
+        cast.Update()
+       
+        laplacian = vtk.vtkImageLaplacian()
+        laplacian.SetInputData(cast.GetOutput())
+        laplacian.SetDimensionality(2)
+        laplacian.Update()
+        
+        subtr = vtk.vtkImageMathematics()
+        subtr.SetInputData(0, cast.GetOutput())
+        subtr.SetInputData(1, laplacian.GetOutput())
+        subtr.SetOperationToSubtract()
+        subtr.Update()    
+        
+        colorWindow = scalarRange[1] - scalarRange[0]
+        colorLevel = colorWindow / 2    
+        originalColor = vtk.vtkImageMapToWindowLevelColors()
+        originalColor.SetWindow(colorWindow)
+        originalColor.SetLevel(colorLevel)
+        originalColor.SetInputData(subtr.GetOutput())
+        originalColor.Update()        
+        return self._update(originalColor.GetOutput())
 
     def fft(self, mode='magnitude', logscale=12, center=True):
         """Fast Fourier transform of a picture.
@@ -619,6 +709,76 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         blf.SetBlendModeToNormal()
         blf.Update()
         return self._update(blf.GetOutput())
+    
+    
+    def warp(self, sourcePts=(), targetPts=(), transform=None, sigma=1, 
+             mirroring=False, bc='w', alpha=1):
+        """
+        Warp an image using thin-plate splines.
+
+        Parameters
+        ----------
+        sourcePts : list, optional
+            source points. 
+        targetPts : list, optional
+            target points.
+        transform : TYPE, optional
+            a vtkTransform object can be supplied. The default is None.
+        sigma : float, optional
+            stiffness of the interpolation. The default is 1.
+        mirroring : TYPE, optional
+            fill the margins with a reflection of the original image. The default is False.
+        bc : TYPE, optional
+            fill the margins with a solid color. The default is 'w'.
+        alpha : TYPE, optional
+            opacity of the filled margins. The default is 1.
+        """
+        if transform is None:
+            # source and target must be filled
+            transform = vtk.vtkThinPlateSplineTransform()
+            transform.SetBasisToR2LogR()
+            if isinstance(sourcePts, vedo.Points):
+                sourcePts = sourcePts.points()
+            if isinstance(targetPts, vedo.Points):
+                targetPts = targetPts.points()
+    
+            ns = len(sourcePts)
+            nt = len(targetPts)
+            if ns != nt:
+                colors.printc("Error in picture.warp(): #source != #target points", ns, nt, c='r')
+                raise RuntimeError()
+                
+            ptsou = vtk.vtkPoints()
+            ptsou.SetNumberOfPoints(ns)   
+    
+            pttar = vtk.vtkPoints()
+            pttar.SetNumberOfPoints(nt)
+            
+            for i in range(ns):
+                p = sourcePts[i]
+                ptsou.SetPoint(i, [p[0],p[1],0])
+                p = targetPts[i]
+                pttar.SetPoint(i, [p[0],p[1],0])
+
+            transform.SetSigma(sigma)
+            transform.SetSourceLandmarks(pttar)
+            transform.SetTargetLandmarks(ptsou)
+        else:
+            # ignore source and target
+            pass
+        
+        reslice = vtk.vtkImageReslice()
+        reslice.SetInputData(self._data)
+        reslice.SetOutputDimensionality(2)
+        reslice.SetResliceTransform(transform)
+        reslice.SetInterpolationModeToCubic()
+        reslice.SetMirror(mirroring)
+        c = np.array(colors.getColor(bc))*255
+        reslice.SetBackgroundColor([c[0],c[1],c[2], alpha*255])
+        reslice.Update()
+        self.transform = transform
+        return self._update(reslice.GetOutput())
+    
 
     def threshold(self, value=None, flip=False):
         """
@@ -673,6 +833,13 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         gr.pos(int(dims[0]/2), int(dims[1]/2)).pickable(True).wireframe(False).lw(0)
         self._data.GetPointData().GetScalars().SetName("RGBA")
         gr.inputdata().GetPointData().AddArray(self._data.GetPointData().GetScalars())
+        gr.inputdata().GetPointData().SetActiveScalars("RGBA")
+        gr._mapper.SetArrayName("RGBA")
+        gr._mapper.SetScalarModeToUsePointData()
+        # gr._mapper.SetColorModeToDirectScalars()
+        gr._mapper.ScalarVisibilityOn()
+        gr.name = self.name
+        gr.filename = self.filename
         return gr
 
     def tonumpy(self):
@@ -689,8 +856,8 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         """
         nx, ny, _ = self._data.GetDimensions()
         nchan = self._data.GetPointData().GetScalars().GetNumberOfComponents()
-        narray = utils.vtk2numpy(self._data.GetPointData().GetScalars()).reshape(nchan, ny,nx)
-        # narray = np.transpose(narray, axes=[1, 0])
+        narray = utils.vtk2numpy(self._data.GetPointData().GetScalars()).reshape(ny,nx,nchan)
+        narray = np.flip(narray, axis=0)
         return narray
     
     def modified(self):
