@@ -24,7 +24,7 @@ def delaunay3D(mesh, alphaPar=0, tol=None, boundary=False):
     if utils.isSequence(mesh):
         pd = vtk.vtkPolyData()
         vpts = vtk.vtkPoints()
-        vpts.SetData(utils.numpy2vtk(mesh, dtype=np.float))
+        vpts.SetData(utils.numpy2vtk(mesh, dtype=float))
         pd.SetPoints(vpts)
         deln.SetInputData(pd)
     else:
@@ -176,7 +176,7 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
             cells = tets
 
         sourcePoints = vtk.vtkPoints()
-        varr = utils.numpy2vtk(points, dtype=np.float)
+        varr = utils.numpy2vtk(points, dtype=float)
         sourcePoints.SetData(varr)
         ug.SetPoints(sourcePoints)
 
@@ -225,12 +225,11 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         th.SetInputData(self._data)
 
         if name is None:
-            ns = self.getArrayNames()
-            if len(ns['CellData']):
-                name=ns['CellData'][0]
+            if len(self.celldata.keys()):
+                name = self.celldata.keys()[0]
                 th.SetInputArrayToProcess(0,0,0, 1, name)
-            elif len(ns['PointData']):
-                name=ns['PointData'][0]
+            elif len(self.pointdata.keys()):
+                name = self.pointdata.keys()[0]
                 th.SetInputArrayToProcess(0,0,0, 0, name)
             if name is None:
                 printc("threshold(): Cannot find active array. Skip.", c='r')
